diff --git a/src/Plugin/Block/FieldBlock.php b/src/Plugin/Block/FieldBlock.php
index 477877b7ccc3289111a2f5bc8ebe01c83b970b95..a225157aa57a63f3e8222588f4d57ad9bb0d1492 100644
--- a/src/Plugin/Block/FieldBlock.php
+++ b/src/Plugin/Block/FieldBlock.php
@@ -356,8 +356,8 @@ class FieldBlock extends BlockBase implements ContainerFactoryPluginInterface {
    * {@inheritdoc}
    */
   public function getCacheContexts() {
     // This block must be cached per URL: every entity has its own canonical url
     // and its own fields.
-    return ['url'];
+    return ['route'];
   }
 }
@@ -356,8 +356,8 @@ class FieldBlock extends BlockBase implements ContainerFactoryPluginInterface {
    */
   public function getCacheContexts() {
-    // This block must be cached per URL: every entity has its own canonical url
+    // This block must be cached per route: every entity has its own canonical url
     // and its own fields.